import { Application, Utils } from "@nativescript/core";
import { createSavingsDeactivationIntent } from "../intents.android";
import { getLogger } from "../../../../../utils/logger";
import { fireInMs, waitForActivityResume } from "./perm-request-common";
const MS_TO_UPDATE = 1000;
export class PowerSavingsManager {
    constructor(powerManager = Utils.android
        .getApplicationContext()
        .getSystemService(android.content.Context.POWER_SERVICE), skdVersion = android.os.Build.VERSION.SDK_INT, activityGetter = () => Application.android.foregroundActivity) {
        this.powerManager = powerManager;
        this.skdVersion = skdVersion;
        this.activityGetter = activityGetter;
        this.logger = getLogger("PowerSavingsManager");
        this.appPackage = Utils.android.getApplicationContext().getPackageName();
    }
    areDisabled() {
        if (this.skdVersion < 23) {
            return true;
        }
        return this.powerManager.isIgnoringBatteryOptimizations(this.appPackage);
    }
    async requestDeactivation() {
        if (this.askedOnce || this.areDisabled()) {
            return;
        }
        const visibleActivity = this.activityGetter();
        if (!visibleActivity) {
            this.logger.warn("Battery savings can not be enabled in background");
            return;
        }
        this.askedOnce = true;
        const activityResume = waitForActivityResume();
        const intent = createSavingsDeactivationIntent(this.appPackage);
        visibleActivity.startActivity(intent);
        await activityResume;
        await fireInMs(MS_TO_UPDATE);
        if (!this.areDisabled()) {
            throw new Error("Disabling battery optimizations is required for the app to work as expected!");
        }
    }
}
let powerSavingsManager;
export function getPowerSavingsManager() {
    if (!powerSavingsManager) {
        powerSavingsManager = new PowerSavingsManager();
    }
    return powerSavingsManager;
}
//# sourceMappingURL=power-savings-manager.android.js.map