import { ApplicationSettings } from "@nativescript/core";
import { now } from "../../../utils/time";
const PLANNING_TIMESTAMPS = "PLANNING_TIMESTAMPS";
class PlanningTimestamp {
    constructor() {
        const timestamps = this.getTimestamps();
        this._previous = timestamps.previous;
        this._current = timestamps.current;
    }
    get previous() {
        return this._previous;
    }
    get current() {
        return this._current;
    }
    updateCurrent() {
        const previousCurrent = this.current;
        const newCurrent = now();
        this._previous = previousCurrent;
        this._current = newCurrent;
        this.setTimestamps({ previous: this.previous, current: this.current });
    }
    getTimestamps() {
        const stringifiedTimestamps = ApplicationSettings.getString(PLANNING_TIMESTAMPS, undefined);
        if (!stringifiedTimestamps) {
            return {
                previous: -1,
                current: -1
            };
        }
        return JSON.parse(stringifiedTimestamps);
    }
    setTimestamps(timestamps) {
        const stringifiedTimestamps = JSON.stringify(timestamps);
        ApplicationSettings.setString(PLANNING_TIMESTAMPS, stringifiedTimestamps);
        ApplicationSettings.flush();
    }
}
export const planningTimestamp = new PlanningTimestamp();
//# sourceMappingURL=planning-timestamp.js.map